#!/bin/sh
#                Licensed Materials - Property of IBM
#                      Product Number 5697-ENV
#     (C) Copyright IBM Corp. 1994, 2005.  All rights reserved.
#
#    US Government Users Restricted Rights - Use, duplication or
#    disclosure restricted by GSA ADP Schedule Contract with IBM Corporation.
#
GEM_ROOT="/TDS/server"
PATH=$PATH:/usr/ucb

syntax()
 {
   echo
   echo "unix.setup.sh"
   echo
   echo "  syntax:   unix.setup.sh [ -? ]"
   echo
   echo "  usage:    you must be root to run this script"
   echo
   echo
 }


for i in $@
do
  if [ "$i" = "-?" ]
   then
     syntax
     exit 0
   else
     echo
     echo .... ERROR - invalid flag \"$i\" entered.
     syntax
     exit 1
  fi
done

echo "Server setup starting"

#
# UNIX unique processing
#
if [ "`uname`" = "AIX" ] || [ "`uname`" = "Linux" ] ; then
  if [ "`whoami`" != "root" ] ; then
   echo
   echo ".... You must be the super-user (root) to run this script"
   syntax
   exit 1
  fi

  echo ".... Setting Tivoli environment variables."

  if [ -n "$TSERVER_ETC" ] ; then
    if [ -f $TSERVER_ETC/setup_env.sh ] ; then
      . $TSERVER_ETC/setup_env.sh
    else
      echo ".... Unable to find file $TSERVER_ETC/setup_env.sh"
      echo ".... Tivoli enviroment variables can not be set."
      exit 1
    fi
  elif [ -f /etc/Tivoli/setup_env.sh ] ; then
   . /etc/Tivoli/setup_env.sh
  else
    echo ".... Unable to find file /etc/Tivoli/setup_env.sh"
    echo ".... Tivoli enviroment variables can not be set."
    exit 1
  fi

  #
  # Ensure LANG is set
  #
  if [ -n "$LANG" ] ; then
    if [ ! -d $BINDIR$GEM_ROOT/msg_cat/$LANG ] ; then
      LANG=C
      export LANG
    fi
  else
    LANG=C
    export LANG
  fi
  echo 'LANG.....' $LANG

  #
  # Detemine the OS and set OS-specific paths, falling back to defaults
  # for AIX.
  #

  arch=`uname -s 2> /dev/null`
  if [ "$arch" = "" ] ; then
   echo ".... Unable to determine your OS."
   exit 1
  fi
  archrev=`uname -r | cut -c1`
  if [ "$arch" = "AIX" ] ; then
   NLSBASE1=/usr/lib/nls/msg
   NLSBASE2=/usr/dt/lib/nls/msg
   RESBASE1=/usr/lib/X11/app-defaults
   RESBASE2=/usr/lib/X11/
   RESBASE3=/usr/dt/app-defaults/
   MK_GROUP=/usr/bin/mkgroup
  elif [ "$arch" = "Linux" ]; then
   NLSBASE1="0"
   NLSBASE2="0"
   RESBASE1=/usr/lib/X11/app-defaults
   RESBASE2=/usr/lib/X11
   RESBASE3="0"
   MK_GROUP=/usr/sbin/groupadd
  else
   NLSBASE1=/usr/lib/nls/msg
   NLSBASE2=/usr/dt/lib/nls/msg
   RESBASE1="0"
   RESBASE2="0"
   RESBASE3=/usr/dt/app-defaults/
   MK_GROUP=/usr/sbin/mkgroup
  fi
  export LANG CATFILE NLSBASE1 NLSBASE2 RESBASE1 RESBASE2 RESBASE3 MK_GROUP

  echo .... Creating $arch message catalog and ddf links
  if [ "$arch" = "AIX" ] ; then

   for THELOOP in "1" "2" "3" "4" "5" "6" "7" "8"  ; do
     if   [ "$THELOOP" = "1" ] ; then
       THELANG=Ja_JP
       NEWLANG=Ja_JP.IBM-943
     elif [ "$THELOOP" = "2" ] ; then
       THELANG=Ja_JP
       NEWLANG=Ja_JP.IBM-932
     elif [ "$THELOOP" = "3" ] ; then
       THELANG=ja_JP
       NEWLANG=ja_JP.IBM-eucJP
     elif [ "$THELOOP" = "4" ] ; then
       THELANG=En_US
       NEWLANG=En_US.IBM-850
     elif [ "$THELOOP" = "5" ] ; then
       THELANG=en_US
       NEWLANG=en_US.ISO8859-1
     elif [ "$THELOOP" = "6" ] ; then
       THELANG=Fr_FR
       NEWLANG=Fn_FR.IBM-850
     elif [ "$THELOOP" = "7" ] ; then
       THELANG=fr_FR
       NEWLANG=fr_FR.ISO8859-1
     elif [ "$THELOOP" = "8" ] ; then
       THELANG=pt_BR
       NEWLANG=pt_BR.ISO8859-1
     else
       THELANG=ja_JP
       NEWLANG=ja_JP.IBM-eucJP
     fi

     for LINKDIR in $BINDIR$GEM_ROOT/msg_cat $BINDIR$GEM_ROOT/config/ddf ; do
       if [ -d $LINKDIR/$THELANG ] ; then
         if [ ! -d $LINKDIR/$NEWLANG ] ; then
           mkdir $LINKDIR/$NEWLANG
         fi

         cd $LINKDIR/$THELANG

         for CATFILE in `ls` ; do
           if [ -f $LINKDIR/$NEWLANG/$CATFILE ] || [ -h $LINKDIR/$NEWLANG/$CATFILE ] ; then
             rm $LINKDIR/$NEWLANG/$CATFILE
           fi

           echo .... Creating symbolic links for message catalogs $LINKDIR/$NEWLANG/$CATFILE
           ln -s $LINKDIR/$THELANG/$CATFILE $LINKDIR/$NEWLANG/$CATFILE
         done
       fi
     done
   done

  elif [ "$arch" = "Linux"  ] ; then

   for THELOOP in "1" ; do
     if    [ "$THELOOP" = "1" ] ; then
       THELANG=En_US
       NEWLANG=En_US.IBM850
     else
       THELANG=en_US
       NEWLANG=en_US.ISO_8859-1
     fi

     for LINKDIR in $BINDIR$GEM_ROOT/msg_cat $BINDIR$GEM_ROOT/config/ddf ; do
       if [ -d $LINKDIR/$THELANG ] ; then
         if [ ! -d $LINKDIR/$NEWLANG ] ; then
           mkdir $LINKDIR/$NEWLANG
         fi

         cd $LINKDIR/$THELANG

         for CATFILE in `ls` ; do
           if [ -f $LINKDIR/$NEWLANG/$CATFILE ] || [ -h $LINKDIR/$NEWLANG/$CATFILE ] ; then
             rm $LINKDIR/$NEWLANG/$CATFILE
           fi

           echo .... Creating symbolic links for message catalogs $LINKDIR/$NEWLANG/$CATFILE
           ln -s $LINKDIR/$THELANG/$CATFILE $LINKDIR/$NEWLANG/$CATFILE
         done
       fi
     done
   done

  else
    echo "ERROR:  Architecture $arch is not supported.  Message catalogs will not be linked"
  fi

  #
  # Symlink all of the .cat files to the specified locales.
  #
  echo ".... Creating system message catalog links."

  cd $BINDIR$GEM_ROOT/msg_cat

  for TLANG in `ls` ; do
    for NLSBASE in $NLSBASE1 $NLSBASE2 ; do
      if [ -d $NLSBASE ] ; then
        if [ -d $NLSBASE/$TLANG ] ; then
          cd $BINDIR$GEM_ROOT/msg_cat/$TLANG
          for CATFILE in `ls` ; do
            if [ -f $NLSBASE/$TLANG/$CATFILE ] || [ -h $NLSBASE/$TLANG/$CATFILE ] ; then
              rm $NLSBASE/$TLANG/$CATFILE
            fi

            echo .... Creating symbolic links for message catalogs $NLSBASE/$TLANG/$CATFILE
            ln -s $BINDIR$GEM_ROOT/msg_cat/$TLANG/$CATFILE $NLSBASE/$TLANG/$CATFILE
          done
        else
          echo .... The system $NLSBASE/$TLANG message catalogs are not installed on this system.
          echo .... Message catalog links for $TLANG will not be set.
          echo .... If in the future the system $TLANG catalogs are installed, then
          echo .... unix.setup.sh should be re-run to setup this link.
        fi
      fi
    done
  done

  #
  # Get X resources installed in the proper app-defaults directories
  # Ihsecped is nolonger used, remove any leftover links
  #
  echo "....Creating X resource links"

  if [ "$arch" = "AIX" ] ; then
    if [ "$RESBASE1" != "0" ] ; then
      if [ -f $RESBASE1/Ihsecped ]  || [ -h $RESBASE1/Ihsecped ] ; then
        rm $RESBASE1/Ihsecped
      fi

      # echo .... Creating symbolic links for X resource $RESBASE1/Ihsecped.
      # ln -sf $BINDIR$GEM_ROOT/msg_cat/C/Ihsecped $RESBASE1/Ihsecped
    fi

    if [ "$RESBASE2" != "0" ] ; then
      cd $BINDIR$GEM_ROOT/msg_cat
      for TLANG in `ls` ; do
        if [ -d $RESBASE2$TLANG/app-defaults ] ; then
          if [ -f $RESBASE2$TLANG/app-defaults/Ihsecped ]  || [ -h $RESBASE2$TLANG/app-defaults/Ihsecped ] ; then
            rm $RESBASE2$TLANG/app-defaults/Ihsecped
          fi

          # echo .... Creating symbolic links for X resource $RESBASE2$TLANG/app-defaults/Ihsecped.
          # ln -sf $BINDIR$GEM_ROOT/msg_cat/$TLANG/Ihsecped $RESBASE2$TLANG/app-defaults/Ihsecped
        fi
      done
    fi

    cd $BINDIR$GEM_ROOT/msg_cat
    for TLANG in `ls` ; do
      if [ -d $RESBASE3$TLANG ] ; then
        if [ -f $RESBASE3$TLANG/Ihsecped ]  || [ -h $RESBASE3$TLANG/Ihsecped ] ; then
          rm $RESBASE3$TLANG/Ihsecped
        fi

        # echo .... Creating symbolic links for X resource $RESBASE3$TLANG/Ihsecped.
        # ln -sf $BINDIR$GEM_ROOT/msg_cat/$TLANG/Ihsecped $RESBASE3$TLANG/Ihsecped
      fi
    done
  fi

  #
  # Make symlinks from Tivoli msg_cat to GEM's messages.
  #
  echo ".... Link message catalogs from Tivoli msg_cat directory."

  cd $BINDIR
  cd ../..

  if [ -d "msg_cat" ] ; then
    cd msg_cat

    TIV_MSGCAT=`pwd`

    for TLANG in `ls` ; do
      if [ -d $BINDIR$GEM_ROOT/msg_cat/$TLANG ] ; then

        cd $BINDIR$GEM_ROOT/msg_cat/$TLANG

        for CATFILE in `ls` ; do
          #
          # Remove the symlink if it exists.
          #
          if [ -h $TIV_MSGCAT/$TLANG/$CATFILE ] ; then
            echo ".... Removing $TIV_MSGCAT/$TLANG/$CATFILE from Tivoli message catalog."
            rm $TIV_MSGCAT/$TLANG/$CATFILE
          fi

          echo .... Creating symbolic links for message catalogs $TIV_MSGCAT/$TLANG/$CATFILE
          ln -f -s $BINDIR$GEM_ROOT/msg_cat/$TLANG/$CATFILE $TIV_MSGCAT/$TLANG/$CATFILE
        done
      else
        echo ".... Links from Tivoli $TIV_MSGCAT/$TLANG to msg_cat were not built."
        echo ".... The $BINDIR$GEM_ROOT/msg_cat/$TLANG messages are not installed."
        echo ".... This is not an error."
      fi
    done
  fi

  #
  # Check for and symbolically link libraries.
  #
  echo ".... Checking for Open Class and Exit Libraries."

  #
  # Adjusting ipfx ipfx2 libraries
  #
  if [ -f $BINDIR$GEM_ROOT/lib/libipfx2.a ] ; then
    if [ ! -f $BINDIR$GEM_ROOT/lib/libipfx.a ] ; then
      cp $BINDIR$GEM_ROOT/lib/libipfx2.a $BINDIR$GEM_ROOT/lib/libipfx.a
    fi
  fi

  for LIBFILE in libibmcls.a libibmuis.a libibmcl.so libibmui.so crt0.o \
           libC.a libxlC.so libipfx.a libipfx2.a libihsi.a
  do
    if [ -f $BINDIR$GEM_ROOT/lib/$LIBFILE ] ; then

      if [ -h /usr/lib/$LIBFILE ] ; then
        echo ".... Checking link for $LIBFILE"
        echo `ls -al /usr/lib/$LIBFILE` | grep GEM > /dev/null
        if [ $? = 0 ] ; then
          echo ".... Removing link for /usr/lib/$LIBFILE"
          rm /usr/lib/$LIBFILE
        else
          echo `ls -al /usr/lib/$LIBFILE` | grep TDS > /dev/null
          if [ $? = 0 ] ; then
            echo ".... Removing link for /usr/lib/$LIBFILE"
            rm /usr/lib/$LIBFILE
          fi
        fi
      fi

      if [ ! -f /usr/lib/$LIBFILE ] ; then
        if [ ! -h /usr/lib/$LIBFILE ] ; then
          echo ".... Creating link for $LIBFILE"
          ln -s $BINDIR$GEM_ROOT/lib/$LIBFILE /usr/lib/$LIBFILE
        fi
      fi

    fi
  done

  #
  # Generate symbolic links to versioned shared libraries for Solaris and
  # other ELF systems.
  #
  for LIBFILE in $BINDIR$GEM_ROOT/lib/lib*.so.1
  do
    LINK=`echo $LIBFILE | sed 's/\.so\.1$/.so/'`
    echo ".... Checking link for `basename $LIBFILE`"
    if [ ! -z "$LINK" -a ! -h "$LINK" ]
    then
      echo ".... Setting link for `basename $LIBFILE`"
      ln -s -f `basename $LIBFILE` $LINK
      ln -s -f `basename $LIBFILE` $LINK
    fi
  done

  #
  # Handle the special case of libipfx2 and libipfx
  #
  if [ -f /usr/lib/libipfx2.a ] ; then
    if [ ! -f /usr/lib/libipfx.a ] ; then
      ln -s /usr/lib/libipfx2.a /usr/lib/libipfx.a
    fi
  fi

  #
  # Copy tserverd.sh to /etc/Tivoli/tserver.sh
  #

  echo ".... Checking the link for the startup script."

  if [ -d /etc/Tivoli ] ; then
    if [ -f /etc/Tivoli/tserver.sh ] || [ -h /etc/Tivoli/tserver.sh ] ; then
      echo ".... Removing existing copy of /etc/Tivoli/tserver.sh"
      rm /etc/Tivoli/tserver.sh
    fi

    echo ".... Copying tserverd.sh to /etc/Tivoli/tserver.sh"
    cp $BINDIR$GEM_ROOT/bin/tserverd.sh /etc/Tivoli/tserver.sh
  else
    echo ".... Unable to copy tserverd.sh to /etc/Tivoli to tserver.sh."
    echo ".... This will prevent the server daemons from being started"
    echo ".... by init at startup."
  fi

  #
  # Ensure that Batch Utility help file is not in bin
  #

  echo ".... Checking for the Batch Utility help file."

  if [ -f $BINDIR$GEM_ROOT/bin/ihse.hlp ] || [ -h $BINDIR$GEM_ROOT/bin/ihse.hlp ] ; then
    echo ".... Removing link for Batch Utility help file in bin."
    rm $BINDIR$GEM_ROOT/bin/ihse.hlp
  fi

  #
  # Symbolic links for db/current directory files
  #
  for TDIR in appdefs backgrounds help icons ; do
    echo ".... Checking links for $BINDIR$GEM_ROOT/db/current/$TDIR files."

    if [ ! -d $BINDIR$GEM_ROOT/db/current/$TDIR ] ; then
      echo ".... Installation error, $BINDIR$GEM_ROOT/db/current/$TDIR missing."
    else
      echo ".... Removing any existing links in $BINDIR$GEM_ROOT/db/current/$TDIR"
      cd $BINDIR$GEM_ROOT/db/current/$TDIR
      for FILE_LIST in `ls` ; do
        if [ -f $BINDIR$GEM_ROOT/db/default/$TDIR/$FILE_LIST ] ; then
          if [ -h $BINDIR$GEM_ROOT/db/current/$TDIR/$FILE_LIST ] ; then
            rm  $BINDIR$GEM_ROOT/db/current/$TDIR/$FILE_LIST
          fi
        elif [ -h $BINDIR$GEM_ROOT/db/current/$TDIR/$FILE_LIST ] ; then
          rm  $BINDIR$GEM_ROOT/db/current/$TDIR/$FILE_LIST
        fi
      done

      echo ".... Creating $BINDIR$GEM_ROOT/db/current/$TDIR links."
      cd $BINDIR$GEM_ROOT/db/default/$TDIR
      for FILE_LIST in `ls` ; do
        if [ ! -f $BINDIR$GEM_ROOT/db/current/$TDIR/$FILE_LIST ] && [ ! -h $BINDIR$GEM_ROOT/db/current/$TDIR/$FILE_LIST ] ; then
          ln -s $BINDIR$GEM_ROOT/db/default/$TDIR/$FILE_LIST $BINDIR$GEM_ROOT/db/current/$TDIR/$FILE_LIST
        fi
      done
    fi
  done

  #
  # Add groups to /etc/group if not already defined
  #
  foundAdm="no"
  foundUser="no"

  for GRLIST in `cut -f 1 -d: /etc/group`
  do
    if [ "tsadmn" =  "$GRLIST" ] ; then
      echo ".... Group tsadmn previously defined."
      foundAdm="yes"
    fi

    if [ "tsuser" =  "$GRLIST" ] ; then
      echo ".... Group tsuser previously defined."
      foundUser="yes"
    fi
  done

  if [ $foundAdm = "no" ] ; then
    echo ".... Updating /etc/group - adding tsadmn."
    $MK_GROUP tsadmn
  fi

  if [ $foundUser = "no" ] ; then
    echo ".... Updating /etc/group - adding tsuser."
    $MK_GROUP tsuser
  fi

  #
  # Ensure mode for log and ipc directories
  #
  for DIR_NAME in ipc ipc/SEM ipc/QUEUES log ; do
    chmod 775 $BINDIR$GEM_ROOT/$DIR_NAME
  done

  #
  # Migrate old hostcmd password file ihsshostc.cfg if present
  #
  if [ -f $BINDIR$GEM_ROOT/config/ihsshostc.cfg ] ; then
    echo ".... migrating hostcmd password file"
    $BINDIR$GEM_ROOT/bin/tserver hostcmdoper -a
  fi
  
  #
  # Copy default certificate database files to security directory if none already present
  #
  if [ ! -f $BINDIR$GEM_ROOT/security/nmckeydb.kdb ] ; then
    echo ".... copying certificate database files"
    cp $BINDIR$GEM_ROOT/security/default/nmckeydb.kdb $BINDIR$GEM_ROOT/security/nmckeydb.kdb
    cp $BINDIR$GEM_ROOT/security/default/nmckeydb.sth $BINDIR$GEM_ROOT/security/nmckeydb.sth
    cp $BINDIR$GEM_ROOT/security/default/nmckeydb.rdb $BINDIR$GEM_ROOT/security/nmckeydb.rdb
    cp $BINDIR$GEM_ROOT/security/default/nmckeydb.crl $BINDIR$GEM_ROOT/security/nmckeydb.crl
  fi

  #
  # end of UNIX unique processing
  #
  
  
  #
  # does not run on windows
  #

fi

#
# if ihstec.cfg exists, merge it with the new ihsxtec.cfg
#
if [ -f $BINDIR/TDS/server/config/ihstec.cfg ] ; then
  cat $BINDIR/TDS/server/config/ihstec.cfg >> $BINDIR/TDS/server/config/ihsxtec.cfg
  rm $BINDIR/TDS/server/config/ihstec.cfg
fi

echo "Server setup is complete for this version of unix.setup.sh"
